# encoding: utf-8

#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
Here resides a separate dialog for proxy setting
"""

import pygtk
import gtk
pygtk.require("2.0")
import os


class ProxyDialog(object):

  def __init__(self, parent):
    """
    client = dslib client instance
    """
    self.parent = parent
    self.builder = gtk.Builder()
    gui_xml = self.parent.fix_ui_xml("proxy_dialog.ui")
    try:
      self.builder.add_from_string(gui_xml.decode('utf-8'))
    except:
      # this fixes problem with different API on windows and PyGTK 2.12
      self.builder.add_from_string(gui_xml.decode('utf-8'), -1)
    self.builder.connect_signals(self)
    self.dialog = self.builder.get_object("proxy_dialog")
    #self.radiobutton_no_proxy = self.builder.get_object("radiobutton_no_proxy")
    #self.radiobutton_manual_proxy = self.builder.get_object("radiobutton_manual_proxy")
    #self.radiobutton_auto_proxy = self.builder.get_object("radiobutton_auto_proxy")
    self.manual_config_box = self.builder.get_object("manual_config_box")
    self.auto_proxy_label = self.builder.get_object("auto_proxy_label")
    self._show_auto_proxy()
    self.set_proxy(self.parent.proxy)
    self.dialog.set_transient_for(self.parent.window1)

  def get_proxy(self):
    if self.builder.get_object("radiobutton_no_proxy").get_active():
      return None
    elif self.builder.get_object("radiobutton_auto_proxy").get_active():
      return -1
    else:
      hostname = self.builder.get_object("proxy_hostname").get_text()
      port = self.builder.get_object("proxy_port").get_text()
      return hostname+":"+port
    
  def set_proxy(self, proxy):
    if proxy is None:
      self.builder.get_object("radiobutton_no_proxy").set_active(True)
    elif proxy == -1:
      self.builder.get_object("radiobutton_auto_proxy").set_active(True)
    else:
      pparts = proxy.split(":")
      if len(pparts) == 2:
        hostname, port = pparts
        self.builder.get_object("proxy_hostname").set_text(hostname)
        self.builder.get_object("proxy_port").set_text(port)
        self.builder.get_object("radiobutton_manual_proxy").set_active(True)
      else:
        # wrong data, use auto config
        self.builder.get_object("radiobutton_auto_proxy").set_active(True)
    
  def run(self):
    result = self.dialog.run()
    return result

  def destroy(self):
    self.dialog.destroy()

  def hide(self):
    self.dialog.hide()
    
  def show_all(self):
    self.dialog.show_all()
   
  # -- signal handlers
    
  def on_radiobutton_manual_proxy_toggled(self, w):
    if w.get_active():
      self.manual_config_box.set_sensitive(True)
      self.auto_proxy_label.set_sensitive(False)
    
  def on_radiobutton_auto_proxy_toggled(self, w):
    if w.get_active():
      self.manual_config_box.set_sensitive(False)
      self.auto_proxy_label.set_sensitive(True)
      
  
  def on_radiobutton_no_proxy_toggled(self, w):
    if w.get_active():
      self.manual_config_box.set_sensitive(False)
      self.auto_proxy_label.set_sensitive(False)
    

  # -- private functions
  
  def _show_auto_proxy(self):
    from dslib.client import Client
    proxy = Client.proxy_to_real_proxy(-1)
    if not proxy:
      proxy = _("<i>No proxy detected, direct connection will be used.</i>")
    else:
      proxy = _("<i>Proxy detected</i>: %s" % proxy)
    self.auto_proxy_label.set_markup(proxy)